@@ -9,7 +9,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tclMain.c 1.54 97/08/07 19:04:43
+ * RCS: @(#) $Id: tclMain.c,v 1.4 1998/09/14 18:40:00 stanton Exp $
  */
 
 #include "tcl.h"
@@ -18,6 +18,16 @@
 # undef TCL_STORAGE_CLASS
 # define TCL_STORAGE_CLASS DLLEXPORT
 
+/*
+ * The following code ensures that tclLink.c is linked whenever
+ * Tcl is linked.  Without this code there's no reference to the
+ * code in that file from anywhere in Tcl, so it may not be
+ * linked into the application.
+ */
+
+EXTERN int Tcl_LinkVar();
+int (*tclDummyLinkVarPtr)() = Tcl_LinkVar;
+
 /*
  * Declarations for various library procedures and variables (don't want
  * to include tclPort.h here, because people might copy this file out of
@@ -68,21 +78,6 @@ static int		CheckmemCmd _ANSI_ARGS_((ClientData clientData,
  *----------------------------------------------------------------------
  */
 
-static char consoleScript[] = "\n\
-set loaded [info loaded {}]\n\
-if ![auto_load tkConInit] {\n\
-  error \"cannot start tkcon\"\n\
-}\n\
-foreach pkg $loaded {\n\
-  set name [lindex $pkg 1]\n\
-  set version [package require $name]\n\
-  slave eval package require $name $version\n\
-  unset name version\n\
-}\n\
-catch {unset pkg}\n\
-unset loaded\n\
-";
-
 void
 Tcl_Main(argc, argv, appInitProc)
     int argc;			/* Number of arguments. */
@@ -147,7 +142,7 @@ Tcl_Main(argc, argv, appInitProc)
 	if (errChannel) {
 	    Tcl_Write(errChannel,
 		    "application-specific initialization failed: ", -1);
-	    Tcl_Write(errChannel, Tcl_GetStringResult(interp), -1);
+	    Tcl_Write(errChannel, interp->result, -1);
 	    Tcl_Write(errChannel, "\n", 1);
 	}
     }
@@ -172,6 +167,7 @@ Tcl_Main(argc, argv, appInitProc)
 			Tcl_GetVar(interp, "errorInfo", TCL_GLOBAL_ONLY), -1);
 		Tcl_Write(errChannel, "\n", 1);
 	    }
+	    exitCode = 1;
 	}
 	goto done;
     }
@@ -183,20 +179,6 @@ Tcl_Main(argc, argv, appInitProc)
 
     Tcl_SourceRCFile(interp);
 
-    /*
-     * If standard input is a terminal-like device and the variable
-     * NoTkCon is not set, try to start up TkCon. If this fails,
-     * just continue with the original console.
-     */
-
-    if (tty && !Tcl_GetVar(interp, "NoTkCon", TCL_GLOBAL_ONLY) &&
-	    Tcl_GlobalEval(interp, consoleScript) == TCL_OK) {
-	while (Tcl_DoOneEvent(0)) {
-	    /* empty body loop */
-	}
-	exitCode = 0;
-	goto done;
-    }
     /*
      * Process commands from stdin until there's an end-of-file.  Note
      * that we need to fetch the standard channels again after every
@@ -240,9 +222,6 @@ Tcl_Main(argc, argv, appInitProc)
 		    Tcl_AddErrorInfo(interp,
 			    "\n    (script that generates prompt)");
 		    goto defaultPrompt;
-	        } else if (*Tcl_GetStringResult(interp) && outChannel) {
-	            Tcl_Write(outChannel, Tcl_GetStringResult(interp),
-			    strlen(Tcl_GetStringResult(interp)));
 		}
 	    }
 	    if (outChannel) {
