@@ -8,7 +8,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tclUnixInit.c 1.26 97/08/05 20:09:25
+ * RCS: @(#) $Id: tclUnixInit.c,v 1.11 1998/09/14 18:40:17 stanton Exp $
  */
 
 #include "tclInt.h"
@@ -216,10 +216,7 @@ Tcl_Init(interp)
 	    return (TCL_ERROR);
 	};
     }
-    if (Tcl_Eval(interp, initScript) == TCL_ERROR) {
-	return TCL_ERROR;
-    }
-    return TCL_OK;
+    return(Tcl_Eval(interp, initScript));
 }
 
 /*
@@ -274,7 +271,7 @@ Tcl_SourceRCFile(interp)
 		if (Tcl_EvalFile(interp, fullName) != TCL_OK) {
 		    errChannel = Tcl_GetStdChannel(TCL_STDERR);
 		    if (errChannel) {
-			Tcl_Write(errChannel, Tcl_GetStringResult(interp), -1);
+			Tcl_Write(errChannel, interp->result, -1);
 			Tcl_Write(errChannel, "\n", 1);
 		    }
 		}
